// packages.
const config = require("config");

const express = require("express");
const router = express.Router();

// setup twilio account
const client = require("twilio")(
  config.get("twilio.dev.account_sid"),
  config.get("twilio.dev.auth_token"),
  {
    logLevel: "debug"
  }
);

// application endpoints.
/*
-- health
-- http get
http://localhost:3301/api
*/
router.get("/", (req, res) => {
  return res.status(200).json({ status: "up", info: "application is healthy" });
});

/*
-- send sms message
-- http post
http://localhost:3301/api/sms

-- request body
{
    "to": "PHONE_NUMBER_WITH_PLUS_SYMBOL_AND_COUNTRY_CODE",
    "message": "RANDOM_TEXT"
}
*/
router.post("/sms", (req, res) => {
  // todo - add logic to validate recipient number as per country.
  sendSms(req, res);
});

// helper method
function sendSms(req, res) {
  client.messages
    .create({
      body: req.body.message,
      to: req.body.to,
      from: config.get("twilio.dev.phone_number")
    })
    .then((message) => {
      // console.log(message);
      return res
        .status(202)
        .json({ status: message.status, info: message.sid });
    })
    .catch((err) => {
      // console.log(error);
      return res.status(500).json({ status: "some error occurred", info: err });
    });
}

module.exports = router;
